pub enum KernelFunction {
Linear,
Rbf {
gamma: Float,
},
Polynomial {
degree: i32,
gamma: Float,
coef0: Float,
},
Sigmoid {
gamma: Float,
coef0: Float,
},
Laplacian {
gamma: Float,
},
ChiSquared {
gamma: Float,
},
}Expand description
Kernel functions for Kernel PCA
Variants
Linear
Linear kernel: K(x, y) = <x, y>
Rbf
RBF (Gaussian) kernel: K(x, y) = exp(-gamma * ||x - y||^2)
Polynomial
Polynomial kernel: K(x, y) = (gamma * <x, y> + coef0)^degree
Sigmoid
Sigmoid kernel: K(x, y) = tanh(gamma * <x, y> + coef0)
Laplacian
Laplacian kernel: K(x, y) = exp(-gamma * ||x - y||_1)
ChiSquared
Chi-squared kernel: K(x, y) = exp(-gamma * sum((x_i - y_i)^2 / (x_i + y_i)))
Implementations
Sourceimpl KernelFunction
Kernel selection and validation utilities
impl KernelFunction
Kernel selection and validation utilities
Sourcepub fn evaluate_performance(
&self,
x: &Array2<Float>,
n_components: usize,
cv_folds: usize,
) -> Result<Float>
pub fn evaluate_performance( &self, x: &Array2<Float>, n_components: usize, cv_folds: usize, ) -> Result<Float>
Evaluate kernel performance on given data using cross-validation
Sourcepub fn select_best_kernel(
kernels: &[KernelFunction],
x: &Array2<Float>,
n_components: usize,
cv_folds: usize,
) -> Result<(KernelFunction, Float)>
pub fn select_best_kernel( kernels: &[KernelFunction], x: &Array2<Float>, n_components: usize, cv_folds: usize, ) -> Result<(KernelFunction, Float)>
Select best kernel from a list of candidates using cross-validation
Sourcepub fn generate_kernel_grid() -> Vec<KernelFunction>
pub fn generate_kernel_grid() -> Vec<KernelFunction>
Generate a grid of kernel candidates for hyperparameter tuning